==> gura-0.6.2-src.tar.gz: gura-0.6.2/src/module-wx/Class_wx_XmlResourceHandler.h <==
//----------------------------------------------------------------------------
// wxXmlResourceHandler
// extracted from xmlresh.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_XMLRESOURCEHANDLER_H__
#define __CLASS_WX_XMLRESOURCEHANDLER_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxXmlResourceHandler
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_XmlResourceHandler);

//----------------------------------------------------------------------------
// Object declaration for wxXmlResourceHandler
//----------------------------------------------------------------------------
class Object_wx_XmlResourceHandler : public Object_wx_Object {
public:
	Gura_DeclareObjectAccessor(wx_XmlResourceHandler)
public:
	inline Object_wx_XmlResourceHandler(wxXmlResourceHandler *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Object(Gura_UserClass(wx_XmlResourceHandler), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_XmlResourceHandler(Class *pClass, wxXmlResourceHandler *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Object(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_XmlResourceHandler();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxXmlResourceHandler *GetEntity() {
		return dynamic_cast<wxXmlResourceHandler *>(_pEntity);
	}
	inline wxXmlResourceHandler *ReleaseEntity() {
		wxXmlResourceHandler *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal sig) const {
		if (_pEntity != NULL) return false;
		SetError_InvalidWxObject(sig, "wxXmlResourceHandler");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif

==> gura-0.7.0-src.tar.gz: gura-0.7.0/src/module-wx/Class_wx_XmlResourceHandler.h <==
//----------------------------------------------------------------------------
// wxXmlResourceHandler
// extracted from xmlresh.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_XMLRESOURCEHANDLER_H__
#define __CLASS_WX_XMLRESOURCEHANDLER_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxXmlResourceHandler
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_XmlResourceHandler);

//----------------------------------------------------------------------------
// Object declaration for wxXmlResourceHandler
//----------------------------------------------------------------------------
class Object_wx_XmlResourceHandler : public Object_wx_Object {
public:
	Gura_DeclareObjectAccessor(wx_XmlResourceHandler)
public:
	inline Object_wx_XmlResourceHandler(wxXmlResourceHandler *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Object(Gura_UserClass(wx_XmlResourceHandler), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_XmlResourceHandler(Class *pClass, wxXmlResourceHandler *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Object(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_XmlResourceHandler();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxXmlResourceHandler *GetEntity() {
		return dynamic_cast<wxXmlResourceHandler *>(_pEntity);
	}
	inline wxXmlResourceHandler *ReleaseEntity() {
		wxXmlResourceHandler *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal &sig) const {
		if (_pEntity != nullptr) return false;
		SetError_InvalidWxObject(sig, "wxXmlResourceHandler");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif
